@@ -4,7 +4,6 @@
 #include "BookmarkMgr.h"
 #include "CubicSDR.h"
 #include "DataTree.h"
-#include <wx/string.h>
 
 #define BOOKMARK_RECENTS_MAX 25
 
@@ -16,7 +15,7 @@ BookmarkMgr::BookmarkMgr() {
     rangesSorted = false;
 }
 //
-void BookmarkMgr::saveToFile(std::string bookmarkFn, bool backup, bool useFullpath) {
+void BookmarkMgr::saveToFile(const std::string& bookmarkFn, bool backup, bool useFullpath) {
 
 	std::lock_guard < std::recursive_mutex > lock(busy_lock);
 
@@ -33,7 +32,7 @@ void BookmarkMgr::saveToFile(std::string bookmarkFn, bool backup, bool useFullpa
 
     DataNode *view_ranges = s.rootNode()->newChild("ranges");
 
-    for (auto re_i : ranges) {
+    for (const auto& re_i : ranges) {
         DataNode *range = view_ranges->newChild("range");
         *range->newChild("label") = re_i->label;
         *range->newChild("freq") = re_i->freq;
@@ -69,7 +68,7 @@ void BookmarkMgr::saveToFile(std::string bookmarkFn, bool backup, bool useFullpa
 
     DataNode *recent_modems = s.rootNode()->newChild("recent_modems");
     
-    for (auto demod : wxGetApp().getDemodMgr().getDemodulators()) {
+    for (const auto& demod : wxGetApp().getDemodMgr().getDemodulators()) {
         wxGetApp().getDemodMgr().saveInstance(recent_modems->newChild("modem"),demod);
     }
 
@@ -98,7 +97,7 @@ void BookmarkMgr::saveToFile(std::string bookmarkFn, bool backup, bool useFullpa
     }
 }
 
-bool BookmarkMgr::loadFromFile(std::string bookmarkFn, bool backup, bool useFullpath) {
+bool BookmarkMgr::loadFromFile(const std::string& bookmarkFn, bool backup, bool useFullpath) {
 	
 	std::lock_guard < std::recursive_mutex > lock(busy_lock);
 
@@ -157,10 +156,10 @@ bool BookmarkMgr::loadFromFile(std::string bookmarkFn, bool backup, bool useFull
         if (branches->hasAnother("range")) branches->getNext("range")->element()->get(bRange);
         if (branches->hasAnother("bookmark")) branches->getNext("bookmark")->element()->get(bBookmark);
         if (branches->hasAnother("recent")) branches->getNext("recent")->element()->get(bRecent);
-        wxGetApp().getAppFrame()->getBookmarkView()->setExpandState("active", bActive?true:false);
-        wxGetApp().getAppFrame()->getBookmarkView()->setExpandState("range", bRange?true:false);
-        wxGetApp().getAppFrame()->getBookmarkView()->setExpandState("bookmark", bBookmark?true:false);
-        wxGetApp().getAppFrame()->getBookmarkView()->setExpandState("recent", bRecent?true:false);
+        wxGetApp().getAppFrame()->getBookmarkView()->setExpandState("active", bActive != 0);
+        wxGetApp().getAppFrame()->getBookmarkView()->setExpandState("range", bRange != 0);
+        wxGetApp().getAppFrame()->getBookmarkView()->setExpandState("bookmark", bBookmark != 0);
+        wxGetApp().getAppFrame()->getBookmarkView()->setExpandState("recent", bRecent != 0);
     }
     
     if (s.rootNode()->hasAnother("ranges")) {
@@ -183,20 +182,20 @@ bool BookmarkMgr::loadFromFile(std::string bookmarkFn, bool backup, bool useFull
         DataNode *modems = s.rootNode()->getNext("modems");
         while (modems->hasAnother("group")) {
             DataNode *group = modems->getNext("group");
-            std::string expandState = "true";
+            std::string groupExpandState = "true";
             std::string groupName = "Unnamed";
             if (group->hasAnother("@name")) {
                 groupName = group->getNext("@name")->element()->toString();
             }
             if (group->hasAnother("@expanded")) {
-                expandState = group->getNext("@expanded")->element()->toString();
+                groupExpandState = group->getNext("@expanded")->element()->toString();
             }
-            setExpandState(groupName, (expandState == "true"));
+            setExpandState(groupName, (groupExpandState == "true"));
             while (group->hasAnother("modem")) {
                 DataNode *modem = group->getNext("modem");
                 BookmarkEntryPtr be = nodeToBookmark(modem);
                 if (be) {
-                    addBookmark(groupName.c_str(), be);
+                    addBookmark(groupName, be);
                 } else {
                     std::cout << "error loading bookmarked modem.." << std::endl;
                     loadStatusOk = false;
@@ -227,7 +226,7 @@ bool BookmarkMgr::loadFromFile(std::string bookmarkFn, bool backup, bool useFull
                     wxCopyFile(loadFile.GetFullPath(wxPATH_NATIVE).ToStdString(), lastLoaded.GetFullPath(wxPATH_NATIVE).ToStdString());
                 }
             }
-        } else if (!loadStatusOk) {
+        } else {
             if (loadFile.IsDirWritable()) { // Load failed; keep a copy of the failed bookmark file for analysis?
                 if (loadFile.FileExists() && (!failFile.FileExists() || failFile.IsFileWritable())) {
                     wxCopyFile(loadFile.GetFullPath(wxPATH_NATIVE).ToStdString(), failFile.GetFullPath(wxPATH_NATIVE).ToStdString());
@@ -241,16 +240,27 @@ bool BookmarkMgr::loadFromFile(std::string bookmarkFn, bool backup, bool useFull
 
 void BookmarkMgr::loadDefaultRanges() {
 
-	addRange(std::make_shared<BookmarkRangeEntry>(L"160 Meters", 1900000, 1800000, 2000000));
-	addRange(std::make_shared<BookmarkRangeEntry>(L"80 Meters", 3750000, 3500000, 4000000));
-	addRange(std::make_shared<BookmarkRangeEntry>(L"60 Meters", 5368500, 5332000, 5405000));
-	addRange(std::make_shared<BookmarkRangeEntry>(L"40 Meters", 7150000, 7000000, 7300000));
-	addRange(std::make_shared<BookmarkRangeEntry>(L"30 Meters", 10125000, 10100000, 10150000));
-	addRange(std::make_shared<BookmarkRangeEntry>(L"20 Meters", 14175000, 14000000, 14350000));
-	addRange(std::make_shared<BookmarkRangeEntry>(L"17 Meters", 18068180, 17044180, 19092180));
-	addRange(std::make_shared<BookmarkRangeEntry>(L"15 Meters", 21225000, 21000000, 21450000));
-	addRange(std::make_shared<BookmarkRangeEntry>(L"12 Meters", 24940000, 24890000, 24990000));
-	addRange(std::make_shared<BookmarkRangeEntry>(L"10 Meters", 28850000, 28000000, 29700000));
+    addRange(std::make_shared<BookmarkRangeEntry>(L"2200 Meters (135.7-137.8 kHz)", 136750, 135700, 137800));
+    addRange(std::make_shared<BookmarkRangeEntry>(L"630 Meters (472-479 kHz)", 475500, 472000, 479000));
+	addRange(std::make_shared<BookmarkRangeEntry>(L"160 Meters (1.8-2 MHz)", 1900000, 1800000, 2000000));
+	addRange(std::make_shared<BookmarkRangeEntry>(L"80 Meters (3.5-4.0 MHz)", 3750000, 3500000, 4000000));
+	addRange(std::make_shared<BookmarkRangeEntry>(L"60 Meters (5.332-5.405Mhz)", 5368500, 5332000, 5405000));
+	addRange(std::make_shared<BookmarkRangeEntry>(L"40 Meters (7.0-7.3 MHz)", 7150000, 7000000, 7300000));
+	addRange(std::make_shared<BookmarkRangeEntry>(L"30 Meters (10.1-10.15 MHz)", 10125000, 10100000, 10150000));
+	addRange(std::make_shared<BookmarkRangeEntry>(L"20 Meters (14.0-14.35 MHz)", 14175000, 14000000, 14350000));
+	addRange(std::make_shared<BookmarkRangeEntry>(L"17 Meters (17.044-19.092 MHz)", 18068180, 17044180, 19092180));
+	addRange(std::make_shared<BookmarkRangeEntry>(L"15 Meters (21-21.45 MHz)", 21225000, 21000000, 21450000));
+	addRange(std::make_shared<BookmarkRangeEntry>(L"12 Meters (24.89-24.99 MHz)", 24940000, 24890000, 24990000));
+	addRange(std::make_shared<BookmarkRangeEntry>(L"10 Meters (28-29.7 MHz)", 28850000, 28000000, 29700000));
+    addRange(std::make_shared<BookmarkRangeEntry>(L"6 Meters (50-54 MHz)", 52000000, 50000000, 54000000));
+    addRange(std::make_shared<BookmarkRangeEntry>(L"4 Meters (70-70.5 MHz)", 70250000, 70000000, 70500000));
+    addRange(std::make_shared<BookmarkRangeEntry>(L"2 Meters (144-148 MHz)", 146000000, 144000000, 148000000));
+    addRange(std::make_shared<BookmarkRangeEntry>(L"1.25 Meters (219-225 MHz)", 222000000, 219000000, 225000000));
+    addRange(std::make_shared<BookmarkRangeEntry>(L"70 cm (420-450 MHz)", 435000000, 420000000, 450000000));
+    addRange(std::make_shared<BookmarkRangeEntry>(L"33 cm (902-928 MHz)", 915000000, 902000000, 928000000));
+    addRange(std::make_shared<BookmarkRangeEntry>(L"23 cm (1240-1300 MHz)", 1270000000, 1240000000, 1300000000));
+    addRange(std::make_shared<BookmarkRangeEntry>(L"13 cm lower (2300-2310 MHz)", 2305000000, 2300000000, 2310000000));
+    addRange(std::make_shared<BookmarkRangeEntry>(L"13 cm upper (2390-2450 MHz)", 2420000000, 2390000000, 2450000000));
 }
 
 void BookmarkMgr::resetBookmarks() {
@@ -267,17 +277,17 @@ void BookmarkMgr::resetBookmarks() {
 
 }
 
-bool BookmarkMgr::hasLastLoad(std::string bookmarkFn) {
+bool BookmarkMgr::hasLastLoad(const std::string& bookmarkFn) {
     wxFileName lastLoaded(wxGetApp().getConfig()->getConfigDir(), bookmarkFn + ".lastloaded");
     return lastLoaded.FileExists() && lastLoaded.IsFileReadable();
 }
 
-bool BookmarkMgr::hasBackup(std::string bookmarkFn) {
+bool BookmarkMgr::hasBackup(const std::string& bookmarkFn) {
     wxFileName backupFile(wxGetApp().getConfig()->getConfigDir(), bookmarkFn + ".backup");
     return backupFile.FileExists() && backupFile.IsFileReadable();
 }
 
-void BookmarkMgr::addBookmark(std::string group, DemodulatorInstancePtr demod) {
+void BookmarkMgr::addBookmark(const std::string& group, const DemodulatorInstancePtr& demod) {
     std::lock_guard < std::recursive_mutex > lock(busy_lock);
     
 	//Create a BookmarkEntry from demod data, saving its
@@ -288,7 +298,7 @@ void BookmarkMgr::addBookmark(std::string group, DemodulatorInstancePtr demod) {
     bmDataSorted[group] = false;
 }
 
-void BookmarkMgr::addBookmark(std::string group, BookmarkEntryPtr be) {
+void BookmarkMgr::addBookmark(const std::string& group, const BookmarkEntryPtr& be) {
     std::lock_guard < std::recursive_mutex > lock(busy_lock);
     
     bmData[group].push_back(be);
@@ -296,14 +306,14 @@ void BookmarkMgr::addBookmark(std::string group, BookmarkEntryPtr be) {
 }
 
 
-void BookmarkMgr::removeBookmark(std::string group, BookmarkEntryPtr be) {
+void BookmarkMgr::removeBookmark(const std::string& group, const BookmarkEntryPtr& be) {
     std::lock_guard < std::recursive_mutex > lock(busy_lock);
    
     if (bmData.find(group) == bmData.end()) {
         return;
     }
 
-    BookmarkList::iterator i = std::find(bmData[group].begin(), bmData[group].end(), be);
+    auto i = std::find(bmData[group].begin(), bmData[group].end(), be);
     
     if (i != bmData[group].end()) {
 
@@ -311,22 +321,22 @@ void BookmarkMgr::removeBookmark(std::string group, BookmarkEntryPtr be) {
     }
 }
 
-void BookmarkMgr::removeBookmark(BookmarkEntryPtr be) {
+void BookmarkMgr::removeBookmark(const BookmarkEntryPtr& be) {
     std::lock_guard < std::recursive_mutex > lock(busy_lock);
     
     for (auto &bmd_i : bmData) {
-        BookmarkList::iterator i = std::find(bmd_i.second.begin(), bmd_i.second.end(), be);
+        auto i = std::find(bmd_i.second.begin(), bmd_i.second.end(), be);
         if (i != bmd_i.second.end()) {
             bmd_i.second.erase(i);
         }
     }
 }
 
-void BookmarkMgr::moveBookmark(BookmarkEntryPtr be, std::string group) {
+void BookmarkMgr::moveBookmark(const BookmarkEntryPtr& be, const std::string& group) {
     std::lock_guard < std::recursive_mutex > lock(busy_lock);
     
     for (auto &bmd_i : bmData) {
-        BookmarkList::iterator i = std::find(bmd_i.second.begin(), bmd_i.second.end(), be);
+        auto i = std::find(bmd_i.second.begin(), bmd_i.second.end(), be);
         if (i != bmd_i.second.end()) {
             if (bmd_i.first == group) {
                 return;
@@ -341,7 +351,7 @@ void BookmarkMgr::moveBookmark(BookmarkEntryPtr be, std::string group) {
 }
 
 
-void BookmarkMgr::addGroup(std::string group) {
+void BookmarkMgr::addGroup(const std::string& group) {
     std::lock_guard < std::recursive_mutex > lock(busy_lock);
     
     if (bmData.find(group) == bmData.end()) {
@@ -349,10 +359,10 @@ void BookmarkMgr::addGroup(std::string group) {
     }
 }
 
-void BookmarkMgr::removeGroup(std::string group) {
+void BookmarkMgr::removeGroup(const std::string& group) {
     std::lock_guard < std::recursive_mutex > lock(busy_lock);
     
-    BookmarkMap::iterator i = bmData.find(group);
+    auto i = bmData.find(group);
     
     if (i != bmData.end()) {
        
@@ -360,18 +370,18 @@ void BookmarkMgr::removeGroup(std::string group) {
     }
 }
 
-void BookmarkMgr::renameGroup(std::string group, std::string ngroup) {
+void BookmarkMgr::renameGroup(const std::string& group, const std::string& ngroup) {
     if (group == ngroup) {
         return;
     }
     
     std::lock_guard < std::recursive_mutex > lock(busy_lock);
     
-    BookmarkMap::iterator i = bmData.find(group);
-    BookmarkMap::iterator it = bmData.find(ngroup);
+    auto i = bmData.find(group);
+    auto it = bmData.find(ngroup);
     
     if (i != bmData.end() && it != bmData.end()) {
-        for (auto ii : bmData[group]) {
+        for (const auto& ii : bmData[group]) {
             bmData[ngroup].push_back(ii);
         }
         bmData.erase(group);
@@ -381,7 +391,7 @@ void BookmarkMgr::renameGroup(std::string group, std::string ngroup) {
     }
 }
 
-BookmarkList BookmarkMgr::getBookmarks(std::string group) {
+BookmarkList BookmarkMgr::getBookmarks(const std::string& group) {
     std::lock_guard < std::recursive_mutex > lock(busy_lock);
     
     if (bmData.find(group) == bmData.end()) {
@@ -389,7 +399,7 @@ BookmarkList BookmarkMgr::getBookmarks(std::string group) {
     }
     
     if (!bmDataSorted[group]) {
-        std::sort(bmData[group].begin(), bmData[group].end(), BookmarkEntryCompare());
+		std::sort(bmData[group].begin(), bmData[group].end(), [](const BookmarkEntryPtr a, const BookmarkEntryPtr b) -> bool { return a->frequency < b->frequency;});
         bmDataSorted[group] = true;
     }
     
@@ -400,28 +410,28 @@ BookmarkList BookmarkMgr::getBookmarks(std::string group) {
 void BookmarkMgr::getGroups(BookmarkNames &arr) {
     std::lock_guard < std::recursive_mutex > lock(busy_lock);
 
-    for (BookmarkMap::iterator i = bmData.begin(); i!= bmData.end(); ++i) {
-        arr.push_back(i->first);
+    for (auto & i : bmData) {
+        arr.push_back(i.first);
     }
 }
 
 void BookmarkMgr::getGroups(wxArrayString &arr) {
     std::lock_guard < std::recursive_mutex > lock(busy_lock);
 
-    for (BookmarkMap::iterator i = bmData.begin(); i!= bmData.end(); ++i) {
-        arr.push_back(i->first);
+    for (auto & i : bmData) {
+        arr.push_back(i.first);
     }
 }
 
 
-void BookmarkMgr::setExpandState(std::string groupName, bool state) {
+void BookmarkMgr::setExpandState(const std::string& groupName, bool state) {
 	std::lock_guard < std::recursive_mutex > lock(busy_lock);
 
     expandState[groupName] = state;
 }
 
 
-bool BookmarkMgr::getExpandState(std::string groupName) {
+bool BookmarkMgr::getExpandState(const std::string& groupName) {
 	
 	std::lock_guard < std::recursive_mutex > lock(busy_lock);
 
@@ -454,7 +464,7 @@ void BookmarkMgr::updateBookmarks() {
     }
 }
 
-void BookmarkMgr::updateBookmarks(std::string group) {
+void BookmarkMgr::updateBookmarks(const std::string& group) {
 
     BookmarkView *bmv = wxGetApp().getAppFrame()->getBookmarkView();
     
@@ -464,7 +474,7 @@ void BookmarkMgr::updateBookmarks(std::string group) {
 }
 
 
-void BookmarkMgr::addRecent(DemodulatorInstancePtr demod) {
+void BookmarkMgr::addRecent(const DemodulatorInstancePtr& demod) {
     std::lock_guard < std::recursive_mutex > lock(busy_lock);
 
     recents.push_back(demodToBookmarkEntry(demod));
@@ -472,7 +482,7 @@ void BookmarkMgr::addRecent(DemodulatorInstancePtr demod) {
     trimRecents();
 }
 
-void BookmarkMgr::addRecent(BookmarkEntryPtr be) {
+void BookmarkMgr::addRecent(const BookmarkEntryPtr& be) {
     std::lock_guard < std::recursive_mutex > lock(busy_lock);
 
     recents.push_back(be);
@@ -482,10 +492,10 @@ void BookmarkMgr::addRecent(BookmarkEntryPtr be) {
 
 
 
-void BookmarkMgr::removeRecent(BookmarkEntryPtr be) {
+void BookmarkMgr::removeRecent(const BookmarkEntryPtr& be) {
     std::lock_guard < std::recursive_mutex > lock(busy_lock);
     
-    BookmarkList::iterator bm_i = std::find(recents.begin(),recents.end(), be);
+    auto bm_i = std::find(recents.begin(),recents.end(), be);
  
     if (bm_i != recents.end()) {
         recents.erase(bm_i);
@@ -515,17 +525,17 @@ void BookmarkMgr::trimRecents() {
 }
 
 
-void BookmarkMgr::addRange(BookmarkRangeEntryPtr re) {
+void BookmarkMgr::addRange(const BookmarkRangeEntryPtr& re) {
     std::lock_guard < std::recursive_mutex > lock(busy_lock);
     
     ranges.push_back(re);
     rangesSorted = false;
 }
 
-void BookmarkMgr::removeRange(BookmarkRangeEntryPtr re) {
+void BookmarkMgr::removeRange(const BookmarkRangeEntryPtr& re) {
     std::lock_guard < std::recursive_mutex > lock(busy_lock);
     
-    BookmarkRangeList::iterator re_i = std::find(ranges.begin(), ranges.end(), re);
+    auto re_i = std::find(ranges.begin(), ranges.end(), re);
     
     if (re_i != ranges.end()) {
 
@@ -538,7 +548,7 @@ BookmarkRangeList BookmarkMgr::getRanges() {
     std::lock_guard < std::recursive_mutex > lock(busy_lock);
 
     if (!rangesSorted) {
-        std::sort(ranges.begin(), ranges.end(), BookmarkRangeEntryCompare());
+        std::sort(ranges.begin(), ranges.end(), [](const BookmarkRangeEntryPtr a, const BookmarkRangeEntryPtr b) -> bool { return a->freq < b->freq;});
         rangesSorted = true;
     }
     
@@ -553,7 +563,7 @@ void BookmarkMgr::clearRanges() {
 }
 
 
-BookmarkEntryPtr BookmarkMgr::demodToBookmarkEntry(DemodulatorInstancePtr demod) {
+BookmarkEntryPtr BookmarkMgr::demodToBookmarkEntry(const DemodulatorInstancePtr& demod) {
     
     BookmarkEntryPtr be(new BookmarkEntry);
     
@@ -572,7 +582,7 @@ BookmarkEntryPtr BookmarkMgr::demodToBookmarkEntry(DemodulatorInstancePtr demod)
 
 std::wstring BookmarkMgr::getSafeWstringValue(DataNode* node, const std::string& childNodeName) {
     
-    std::wstring decodedWString = L"";
+    std::wstring decodedWString;
 
     if (node != nullptr) {
 
@@ -582,7 +592,7 @@ std::wstring BookmarkMgr::getSafeWstringValue(DataNode* node, const std::string&
         try {
             childNode->element()->get(decodedWString);
 
-        } catch (DataTypeMismatchException e) {
+        } catch (const DataTypeMismatchException &) {
             //2) wstring decode fail, try simple std::string
             std::string decodedStdString;
             try {
@@ -592,7 +602,7 @@ std::wstring BookmarkMgr::getSafeWstringValue(DataNode* node, const std::string&
                 //use wxString for a clean conversion to a wstring:
                 decodedWString = wxString(decodedStdString).ToStdWstring();
 
-            } catch (DataTypeMismatchException e) {
+            } catch (const DataTypeMismatchException &) {
                 //nothing works, return an empty string.
                 decodedWString = L"";
             }
@@ -628,10 +638,10 @@ BookmarkEntryPtr BookmarkMgr::nodeToBookmark(DataNode *node) {
 }
 
 
-std::wstring BookmarkMgr::getBookmarkEntryDisplayName(BookmarkEntryPtr bmEnt) {
+std::wstring BookmarkMgr::getBookmarkEntryDisplayName(const BookmarkEntryPtr& bmEnt) {
     std::wstring dispName = bmEnt->label;
     
-    if (dispName == L"") {
+    if (dispName.empty()) {
         std::string freqStr = frequencyToStr(bmEnt->frequency) + " " + bmEnt->type;
 
         dispName = wxString(freqStr).ToStdWstring();
@@ -640,10 +650,10 @@ std::wstring BookmarkMgr::getBookmarkEntryDisplayName(BookmarkEntryPtr bmEnt) {
     return dispName;
 }
 
-std::wstring BookmarkMgr::getActiveDisplayName(DemodulatorInstancePtr demod) {
+std::wstring BookmarkMgr::getActiveDisplayName(const DemodulatorInstancePtr& demod) {
     std::wstring activeName = demod->getDemodulatorUserLabel();
     
-    if (activeName == L"") {
+    if (activeName.empty()) {
         std::string wstr = frequencyToStr(demod->getFrequency()) + " " + demod->getDemodulatorType();
 
         activeName = wxString(wstr).ToStdWstring();
@@ -652,7 +662,7 @@ std::wstring BookmarkMgr::getActiveDisplayName(DemodulatorInstancePtr demod) {
     return activeName;
 }
 
-void BookmarkMgr::removeActive(DemodulatorInstancePtr demod) {
+void BookmarkMgr::removeActive(const DemodulatorInstancePtr& demod) {
 	
 	if (demod == nullptr) {
 		return;
