@@ -81,7 +81,7 @@ std::string frequencyToStr(long long freq) {
     long double freqTemp;
     
     freqTemp = freq;
-    std::string suffix("");
+    std::string suffix;
     std::stringstream freqStr;
     
     if (freqTemp >= 1.0e9) {
@@ -133,7 +133,7 @@ long long strToFrequency(std::string freqStr) {
         } else if (suffixStr.find_first_of("Hh") != std::string::npos) {
             // ...
         }
-    } else if (numPartStr.find_first_of(".") != std::string::npos || freqTemp <= 3000) {
+    } else if (numPartStr.find_first_of('.') != std::string::npos || freqTemp <= 3000) {
         freqTemp *= 1.0e6;
     }
     
@@ -148,7 +148,7 @@ public:
         m_questionText->SetLabelText(wxT("All attempts to recover bookmarks have failed. \nWould you like to exit without touching any more save files?\nClick OK to exit without saving; or Cancel to continue anyways."));
     }
     
-    void doClickOK() {
+    void doClickOK() override {
         wxGetApp().getAppFrame()->disableSave(true);
         wxGetApp().getAppFrame()->Close(false);
     }
@@ -162,7 +162,7 @@ public:
         m_questionText->SetLabelText(wxT("Sorry; unable to load your bookmarks backup file. \nWould you like to attempt to load the last succssfully loaded bookmarks file?"));
     }
     
-    void doClickOK() {
+    void doClickOK() override {
         if (wxGetApp().getBookmarkMgr().hasLastLoad("bookmarks.xml")) {
             if (wxGetApp().getBookmarkMgr().loadFromFile("bookmarks.xml.lastloaded",false)) {
                 wxGetApp().getBookmarkMgr().updateBookmarks();
@@ -181,7 +181,7 @@ public:
         m_questionText->SetLabelText(wxT("Sorry; unable to load your bookmarks file. \nWould you like to attempt to load the backup file?"));
     }
     
-    void doClickOK() {
+    void doClickOK() override {
         bool loadOk = false;
         if (wxGetApp().getBookmarkMgr().hasBackup("bookmarks.xml")) {
             loadOk = wxGetApp().getBookmarkMgr().loadFromFile("bookmarks.xml.backup",false);
@@ -198,8 +198,22 @@ public:
 };
 
 
+
+class ActionDialogRigError : public ActionDialog {
+public:
+    explicit ActionDialogRigError(const std::string& message) : ActionDialog(wxGetApp().getAppFrame(), wxID_ANY, wxT("Rig Control Error")) {
+        m_questionText->SetLabelText(message);
+    }
+
+    void doClickOK() override {
+    }
+};
+
+
 CubicSDR::CubicSDR() : frequency(0), offset(0), ppm(0), snap(1), sampleRate(DEFAULT_SAMPLE_RATE), agcMode(false)
 {
+        config.load();
+
         sampleRateInitialized.store(false);
         agcMode.store(true);
         soloMode.store(false);
@@ -216,6 +230,27 @@ CubicSDR::CubicSDR() : frequency(0), offset(0), ppm(0), snap(1), sampleRate(DEFA
         *m_glContextAttributes = glSettings;
 }
 
+void CubicSDR::initAudioDevices() const {
+    std::vector<RtAudio::DeviceInfo> devices;
+    std::map<int, RtAudio::DeviceInfo> inputDevices, outputDevices;
+
+    AudioThread::enumerateDevices(devices);
+
+    int i = 0;
+
+    for (auto & device : devices) {
+        if (device.inputChannels) {
+            inputDevices[i] = device;
+        }
+        if (device.outputChannels) {
+            outputDevices[i] = device;
+        }
+        i++;
+    }
+
+    wxGetApp().getDemodMgr().setOutputDevices(outputDevices);
+}
+
 bool CubicSDR::OnInit() {
 
     //use the current locale most appropriate to this system,
@@ -240,7 +275,7 @@ bool CubicSDR::OnInit() {
     }
 
     //Deactivated code to allocate an explicit Console on Windows.
-    //This tends to hang the apllication on heavy demod (re)creation.
+    //This tends to hang the application on heavy demod (re)creation.
     //To continue to debug with std::cout traces, simply run CubicSDR in a MINSYS2 compatble shell on Windows:
     //ex: Cygwin shell, Git For Windows Bash shell....
 #if (0)
@@ -271,6 +306,7 @@ bool CubicSDR::OnInit() {
     Modem::addModemFactory(ModemNBFM::factory, "NBFM", 12500);
     Modem::addModemFactory(ModemFMStereo::factory, "FMS", 200000);
     Modem::addModemFactory(ModemAM::factory, "AM", 6000);
+    Modem::addModemFactory(ModemCW::factory, "CW", 500);
     Modem::addModemFactory(ModemLSB::factory, "LSB", 5400);
     Modem::addModemFactory(ModemUSB::factory, "USB", 5400);
     Modem::addModemFactory(ModemDSB::factory, "DSB", 5400);
@@ -298,6 +334,8 @@ bool CubicSDR::OnInit() {
     devicesFailed.store(false);
     deviceSelectorOpen.store(false);
 
+    initAudioDevices();
+
     // Visual Data
     spectrumVisualThread = new SpectrumVisualDataThread();
     
@@ -503,7 +541,7 @@ int CubicSDR::OnExit() {
 PrimaryGLContext& CubicSDR::GetContext(wxGLCanvas *canvas) {
     PrimaryGLContext *glContext;
     if (!m_glContext) {
-        m_glContext = new PrimaryGLContext(canvas, NULL, GetContextAttributes());
+        m_glContext = new PrimaryGLContext(canvas, nullptr, GetContextAttributes());
     }
     glContext = m_glContext;
 
@@ -521,14 +559,12 @@ void CubicSDR::OnInitCmdLine(wxCmdLineParser& parser) {
 }
 
 bool CubicSDR::OnCmdLineParsed(wxCmdLineParser& parser) {
-    wxString *confName = new wxString;
+    auto *confName = new wxString;
     if (parser.Found("c",confName)) {
-        if (confName) {
+        if (!confName->empty()) {
             config.setConfigName(confName->ToStdString());
         }
     }
-    
-    config.load();
 
 #ifdef BUNDLE_SOAPY_MODS
     if (parser.Found("b")) {
@@ -540,10 +576,10 @@ bool CubicSDR::OnCmdLineParsed(wxCmdLineParser& parser) {
     useLocalMod.store(true);
 #endif
 
-    wxString *modPath = new wxString;
+    auto *modPath = new wxString;
 
     if (parser.Found("m",modPath)) {
-        if (modPath) {
+        if (!modPath->empty()) {
             modulePath = modPath->ToStdString();
         } else {
             modulePath = "";
@@ -566,21 +602,26 @@ void CubicSDR::deviceSelector() {
         return;
     }
     deviceSelectorOpen.store(true);
-    deviceSelectorDialog = new SDRDevicesDialog(appframe);
+    wxRect *winRect = getConfig()->getWindow();
+    wxPoint pos(wxDefaultPosition);
+    if (winRect != nullptr) {
+        pos = wxPoint(winRect->x, winRect->y);
+    }
+    deviceSelectorDialog = new SDRDevicesDialog(appframe, pos);
     deviceSelectorDialog->Show();
 }
 
-void CubicSDR::addRemote(std::string remoteAddr) {
+void CubicSDR::addRemote(const std::string& remoteAddr) {
     SDREnumerator::addRemote(remoteAddr);
     devicesReady.store(false);
     t_SDREnum = new std::thread(&SDREnumerator::threadMain, sdrEnum);
 }
 
-void CubicSDR::removeRemote(std::string remoteAddr) {
+void CubicSDR::removeRemote(const std::string& remoteAddr) {
     SDREnumerator::removeRemote(remoteAddr);
 }
 
-void CubicSDR::sdrThreadNotify(SDRThread::SDRThreadState state, std::string message) {
+void CubicSDR::sdrThreadNotify(SDRThread::SDRThreadState state, const std::string& message) {
 
     std::lock_guard < std::mutex > lock(notify_busy);
 
@@ -725,7 +766,7 @@ void CubicSDR::setSampleRate(long long rate_in) {
 
 void CubicSDR::stopDevice(bool store, int waitMsForTermination) {
     
-    //Firt we must stop the threads
+    //First we must stop the threads
     sdrThread->terminate();
     sdrThread->isTerminated(waitMsForTermination);
 
@@ -841,12 +882,16 @@ DemodulatorThreadInputQueuePtr CubicSDR::getWaterfallVisualQueue() {
     return pipeWaterfallIQVisualData;
 }
 
+BookmarkMgr &CubicSDR::getBookmarkMgr() {
+    return bookmarkMgr;
+}
+
 DemodulatorMgr &CubicSDR::getDemodMgr() {
     return demodMgr;
 }
 
-BookmarkMgr &CubicSDR::getBookmarkMgr() {
-    return bookmarkMgr;
+SessionMgr &CubicSDR::getSessionMgr() {
+    return sessionMgr;
 }
 
 SDRPostThread *CubicSDR::getSDRPostThread() {
@@ -867,7 +912,7 @@ long long CubicSDR::getSampleRate() {
     return sampleRate;
 }
 
-void CubicSDR::removeDemodulator(DemodulatorInstancePtr demod) {
+void CubicSDR::removeDemodulator(const DemodulatorInstancePtr& demod) {
     if (!demod) {
         return;
     }
@@ -904,7 +949,7 @@ int CubicSDR::getPPM() {
     return ppm;
 }
 
-void CubicSDR::showFrequencyInput(FrequencyDialog::FrequencyDialogTarget targetMode, wxString initString) {
+void CubicSDR::showFrequencyInput(FrequencyDialog::FrequencyDialogTarget targetMode, const wxString& initString) {
     const wxString demodTitle("Set Demodulator Frequency");
     const wxString freqTitle("Set Center Frequency");
     const wxString bwTitle("Modem Bandwidth (150Hz - 500KHz)");
@@ -913,11 +958,12 @@ void CubicSDR::showFrequencyInput(FrequencyDialog::FrequencyDialogTarget targetM
     const wxString gainTitle("Gain Entry: "+wxGetApp().getActiveGainEntry());
 
     wxString title;
-    
+    auto activeModem = demodMgr.getActiveContextModem();
+
     switch (targetMode) {
         case FrequencyDialog::FDIALOG_TARGET_DEFAULT:
         case FrequencyDialog::FDIALOG_TARGET_FREQ:
-            title = demodMgr.getActiveDemodulator()?demodTitle:freqTitle;
+            title = activeModem ?demodTitle:freqTitle;
             break;
         case FrequencyDialog::FDIALOG_TARGET_BANDWIDTH:
             title = bwTitle;
@@ -930,21 +976,21 @@ void CubicSDR::showFrequencyInput(FrequencyDialog::FrequencyDialogTarget targetM
             break;
         case FrequencyDialog::FDIALOG_TARGET_GAIN:
             title = gainTitle;
-            if (wxGetApp().getActiveGainEntry() == "") {
+            if (wxGetApp().getActiveGainEntry().empty()) {
                 return;
             }
             break;
         default:
             break;
     }
-    
-    FrequencyDialog fdialog(appframe, -1, title, demodMgr.getActiveDemodulator(), wxPoint(-100,-100), wxSize(350, 75), wxDEFAULT_DIALOG_STYLE, targetMode, initString);
+
+    FrequencyDialog fdialog(appframe, -1, title, activeModem, wxPoint(-100,-100), wxSize(350, 75), wxDEFAULT_DIALOG_STYLE, targetMode, initString);
     fdialog.ShowModal();
 }
 
 void CubicSDR::showLabelInput() {
 
-    DemodulatorInstancePtr activeDemod = wxGetApp().getDemodMgr().getActiveDemodulator();
+    DemodulatorInstancePtr activeDemod = wxGetApp().getDemodMgr().getActiveContextModem();
 
     if (activeDemod != nullptr) {
 
@@ -959,11 +1005,11 @@ AppFrame *CubicSDR::getAppFrame() {
     return appframe;
 }
 
-void CubicSDR::setFrequencySnap(int snap) {
-    if (snap > 1000000) {
-        snap = 1000000;
+void CubicSDR::setFrequencySnap(int snap_in) {
+    if (snap_in > 1000000) {
+        snap_in = 1000000;
     }
-    this->snap = snap;
+    this->snap = snap_in;
 }
 
 int CubicSDR::getFrequencySnap() {
@@ -1019,11 +1065,11 @@ bool CubicSDR::getAGCMode() {
 }
 
 
-void CubicSDR::setGain(std::string name, float gain_in) {
+void CubicSDR::setGain(const std::string& name, float gain_in) {
     sdrThread->setGain(name,gain_in);
 }
 
-float CubicSDR::getGain(std::string name) {
+float CubicSDR::getGain(const std::string& name) {
     return sdrThread->getGain(name);
 }
 
@@ -1124,9 +1170,12 @@ void CubicSDR::stopRig() {
     }
     
     if (rigThread) {
-        
         rigThread->terminate();
         rigThread->isTerminated(1000);
+
+        if (rigThread->getErrorState()) {
+            ActionDialog::showDialog(new ActionDialogRigError(rigThread->getErrorMessage()));
+        }
     }
 
     if (t_Rig && t_Rig->joinable()) {
