@@ -2,13 +2,9 @@
 // SPDX-License-Identifier: GPL-2.0+
 
 #include <DemodulatorMgr.h>
-#include <sstream>
 #include <algorithm>
 #include <string>
-#include <sstream>
-#include <algorithm>
 
-#include "DemodulatorMgr.h"
 #include "CubicSDR.h"
 
 #if USE_HAMLIB
@@ -18,8 +14,8 @@
 #include "DataTree.h"
 #include <wx/string.h>
 
-bool demodFreqCompare (DemodulatorInstancePtr i, DemodulatorInstancePtr j) { return (i->getFrequency() < j->getFrequency()); }
-bool inactiveCompare (DemodulatorInstancePtr i, DemodulatorInstancePtr j) { return (i->isActive() < j->isActive()); }
+bool demodFreqCompare (const DemodulatorInstancePtr& i, const DemodulatorInstancePtr& j) { return (i->getFrequency() < j->getFrequency()); }
+bool inactiveCompare (const DemodulatorInstancePtr& i, const DemodulatorInstancePtr& j) { return (i->isActive() < j->isActive()); }
 
 DemodulatorMgr::DemodulatorMgr() {
 
@@ -55,7 +51,7 @@ void DemodulatorMgr::terminateAll() {
 
     std::lock_guard < std::recursive_mutex > lock(demods_busy);
     
-    while (demods.size()) {
+    while (!demods.empty()) {
 
         DemodulatorInstancePtr d = demods.back();
         demods.pop_back();
@@ -95,9 +91,9 @@ std::vector<DemodulatorInstancePtr> DemodulatorMgr::getOrderedDemodulators(bool
     return demods_ordered;
 }
 
-DemodulatorInstancePtr DemodulatorMgr::getPreviousDemodulator(DemodulatorInstancePtr demod, bool actives) {
+DemodulatorInstancePtr DemodulatorMgr::getPreviousDemodulator(const DemodulatorInstancePtr& demod, bool actives) {
     std::lock_guard < std::recursive_mutex > lock(demods_busy);
-    if (!getLastActiveDemodulator()) {
+    if (!getCurrentModem()) {
         return nullptr;
     }
     auto demods_ordered = getOrderedDemodulators(actives);
@@ -112,9 +108,9 @@ DemodulatorInstancePtr DemodulatorMgr::getPreviousDemodulator(DemodulatorInstanc
     return *(--p);
 }
 
-DemodulatorInstancePtr DemodulatorMgr::getNextDemodulator(DemodulatorInstancePtr demod, bool actives) {
+DemodulatorInstancePtr DemodulatorMgr::getNextDemodulator(const DemodulatorInstancePtr& demod, bool actives) {
     std::lock_guard < std::recursive_mutex > lock(demods_busy);
-    if (!getLastActiveDemodulator()) {
+    if (!getCurrentModem()) {
         return nullptr;
     }
     auto demods_ordered = getOrderedDemodulators(actives);
@@ -144,7 +140,7 @@ DemodulatorInstancePtr DemodulatorMgr::getFirstDemodulator() {
     return getOrderedDemodulators().front();
 }
 
-void DemodulatorMgr::deleteThread(DemodulatorInstancePtr demod) {
+void DemodulatorMgr::deleteThread(const DemodulatorInstancePtr& demod) {
     
     std::lock_guard < std::recursive_mutex > lock(demods_busy);
 
@@ -152,11 +148,11 @@ void DemodulatorMgr::deleteThread(DemodulatorInstancePtr demod) {
   
     auto i = std::find(demods.begin(), demods.end(), demod);
 
-    if (activeDemodulator == demod) {
-        activeDemodulator = nullptr;
+    if (activeContextModem == demod) {
+        activeContextModem = nullptr;
     }
-    if (lastActiveDemodulator == demod) {
-        lastActiveDemodulator = nullptr;
+    if (currentModem == demod) {
+        currentModem = nullptr;
     }
     if (activeVisualDemodulator == demod) {
         activeVisualDemodulator = nullptr;
@@ -176,9 +172,7 @@ std::vector<DemodulatorInstancePtr> DemodulatorMgr::getDemodulatorsAt(long long
     
     std::vector<DemodulatorInstancePtr> foundDemods;
 
-    for (int i = 0, iMax = demods.size(); i < iMax; i++) {
-        DemodulatorInstancePtr testDemod = demods[i];
-
+    for (auto testDemod : demods) {
         long long freqTest = testDemod->getFrequency();
         long long bandwidthTest = testDemod->getBandwidth();
         long long halfBandwidthTest = bandwidthTest / 2;
@@ -195,9 +189,7 @@ std::vector<DemodulatorInstancePtr> DemodulatorMgr::getDemodulatorsAt(long long
 
 bool DemodulatorMgr::anyDemodulatorsAt(long long freq, int bandwidth) {
     std::lock_guard < std::recursive_mutex > lock(demods_busy);
-    for (int i = 0, iMax = demods.size(); i < iMax; i++) {
-        DemodulatorInstancePtr testDemod = demods[i];
-
+    for (auto testDemod : demods) {
         long long freqTest = testDemod->getFrequency();
         long long bandwidthTest = testDemod->getBandwidth();
         long long halfBandwidthTest = bandwidthTest / 2;
@@ -214,26 +206,31 @@ bool DemodulatorMgr::anyDemodulatorsAt(long long freq, int bandwidth) {
 }
 
 
-void DemodulatorMgr::setActiveDemodulator(DemodulatorInstancePtr demod, bool temporary) {
-    
+void DemodulatorMgr::setActiveDemodulator(const DemodulatorInstancePtr& demod, bool temporary) {
+
     std::lock_guard < std::recursive_mutex > lock(demods_busy);
-    
+
+    // Should this be made the current modem (i.e. clicked, toggled)
     if (!temporary) {
-        if (activeDemodulator != nullptr) {
-            lastActiveDemodulator = activeDemodulator;
+        if (activeContextModem != nullptr) {
+            currentModem = activeContextModem;
             updateLastState();
         } else {
-            lastActiveDemodulator = demod;
+            currentModem = demod;
         }
+
         updateLastState();
+
+        wxGetApp().getBookmarkMgr().updateActiveList();
+
 #if USE_HAMLIB
-        if (wxGetApp().rigIsActive() && wxGetApp().getRigThread()->getFollowModem() && lastActiveDemodulator) {
-            wxGetApp().getRigThread()->setFrequency(lastActiveDemodulator->getFrequency(),true);
+        if (wxGetApp().rigIsActive() && wxGetApp().getRigThread()->getFollowModem() && currentModem) {
+            wxGetApp().getRigThread()->setFrequency(currentModem->getFrequency(),true);
         }
 #endif
-        wxGetApp().getBookmarkMgr().updateActiveList();
-    } 
+    }
 
+    // TODO: This is probably unnecessary and confusing
     if (activeVisualDemodulator) {
         activeVisualDemodulator->setVisualOutputQueue(nullptr);
     }
@@ -241,22 +238,22 @@ void DemodulatorMgr::setActiveDemodulator(DemodulatorInstancePtr demod, bool tem
         demod->setVisualOutputQueue(wxGetApp().getAudioVisualQueue());
         activeVisualDemodulator = demod;
     } else {
-        DemodulatorInstancePtr last = getLastActiveDemodulator();
+        DemodulatorInstancePtr last = getCurrentModem();
         if (last) {
             last->setVisualOutputQueue(wxGetApp().getAudioVisualQueue());
         }
         activeVisualDemodulator = last;
     }
+    // :ODOT
 
-    activeDemodulator = demod;
-
+    activeContextModem = demod;
 }
 
 //Dangerous: this is only intended by some internal classes
 void DemodulatorMgr::setActiveDemodulatorByRawPointer(DemodulatorInstance* demod, bool temporary) {
     std::lock_guard < std::recursive_mutex > lock(demods_busy);
 
-    for (auto existing_demod : demods) {
+    for (const auto& existing_demod : demods) {
 
         if (existing_demod.get() == demod) {
 
@@ -266,17 +263,27 @@ void DemodulatorMgr::setActiveDemodulatorByRawPointer(DemodulatorInstance* demod
     }
 }
 
-DemodulatorInstancePtr DemodulatorMgr::getActiveDemodulator() {
+/**
+ * Get the currently focused modem, i.e. the one hovered by interaction
+ * If no active context modem is available the current modem is returned
+ * @return Active Context Modem
+ */
+DemodulatorInstancePtr DemodulatorMgr::getActiveContextModem() {
     std::lock_guard < std::recursive_mutex > lock(demods_busy);
 
-    if (activeDemodulator && !activeDemodulator->isActive()) {
-        activeDemodulator = getLastActiveDemodulator();
+    if (activeContextModem && !activeContextModem->isActive()) {
+        activeContextModem = getCurrentModem();
     }
-    return activeDemodulator;
+    return activeContextModem;
 }
 
-DemodulatorInstancePtr DemodulatorMgr::getLastActiveDemodulator() {
-    return lastActiveDemodulator;
+/**
+ * Get the last selected / focused modem
+ * This is the currently active modem
+ * @return Current Modem
+ */
+DemodulatorInstancePtr DemodulatorMgr::getCurrentModem() {
+    return currentModem;
 }
 
 DemodulatorInstancePtr DemodulatorMgr::getLastDemodulatorWith(const std::string& type,
@@ -304,27 +311,27 @@ DemodulatorInstancePtr DemodulatorMgr::getLastDemodulatorWith(const std::string&
 void DemodulatorMgr::updateLastState() {
     std::lock_guard < std::recursive_mutex > lock(demods_busy);
 
-    if (std::find(demods.begin(), demods.end(), lastActiveDemodulator) == demods.end()) {
-        if (activeDemodulator && activeDemodulator->isActive()) {
-            lastActiveDemodulator = activeDemodulator;
-        } else if (activeDemodulator && !activeDemodulator->isActive()){
-            activeDemodulator = nullptr;
-            lastActiveDemodulator = nullptr;
+    if (std::find(demods.begin(), demods.end(), currentModem) == demods.end()) {
+        if (activeContextModem && activeContextModem->isActive()) {
+            currentModem = activeContextModem;
+        } else if (activeContextModem && !activeContextModem->isActive()){
+            activeContextModem = nullptr;
+            currentModem = nullptr;
         }
     }
 
-    if (lastActiveDemodulator && !lastActiveDemodulator->isActive()) {
-        lastActiveDemodulator = nullptr;
+    if (currentModem && !currentModem->isActive()) {
+        currentModem = nullptr;
     }
 
-    if (lastActiveDemodulator) {
-        lastBandwidth = lastActiveDemodulator->getBandwidth();
-        lastDemodType = lastActiveDemodulator->getDemodulatorType();
-        lastDemodLock = lastActiveDemodulator->getDemodulatorLock()?true:false;
-        lastSquelchEnabled = lastActiveDemodulator->isSquelchEnabled();
-        lastSquelch = lastActiveDemodulator->getSquelchLevel();
-        lastGain = lastActiveDemodulator->getGain();
-        lastModemSettings[lastDemodType] = lastActiveDemodulator->readModemSettings();
+    if (currentModem) {
+        lastBandwidth = currentModem->getBandwidth();
+        lastDemodType = currentModem->getDemodulatorType();
+        lastDemodLock = currentModem->getDemodulatorLock() != 0;
+        lastSquelchEnabled = currentModem->isSquelchEnabled();
+        lastSquelch = currentModem->getSquelchLevel();
+        lastGain = currentModem->getGain();
+        lastModemSettings[lastDemodType] = currentModem->readModemSettings();
     }
 
 }
@@ -333,29 +340,29 @@ int DemodulatorMgr::getLastBandwidth() const {
     return lastBandwidth;
 }
 
-void DemodulatorMgr::setLastBandwidth(int lastBandwidth) {
-    if (lastBandwidth < MIN_BANDWIDTH) {
-        lastBandwidth = MIN_BANDWIDTH;
-    } else  if (lastBandwidth > wxGetApp().getSampleRate()) {
-        lastBandwidth = wxGetApp().getSampleRate();
+void DemodulatorMgr::setLastBandwidth(int lastBandwidth_in) {
+    if (lastBandwidth_in < MIN_BANDWIDTH) {
+        lastBandwidth_in = MIN_BANDWIDTH;
+    } else  if (lastBandwidth_in > wxGetApp().getSampleRate()) {
+        lastBandwidth_in = wxGetApp().getSampleRate();
     }
-    this->lastBandwidth = lastBandwidth;
+    lastBandwidth = lastBandwidth_in;
 }
 
 std::string DemodulatorMgr::getLastDemodulatorType() const {
     return lastDemodType;
 }
 
-void DemodulatorMgr::setLastDemodulatorType(std::string lastDemodType) {
-    this->lastDemodType = lastDemodType;
+void DemodulatorMgr::setLastDemodulatorType(std::string lastDemodType_in) {
+    lastDemodType = lastDemodType_in;
 }
 
 float DemodulatorMgr::getLastGain() const {
     return lastGain;
 }
 
-void DemodulatorMgr::setLastGain(float lastGain) {
-    this->lastGain = lastGain;
+void DemodulatorMgr::setLastGain(float lastGain_in) {
+    lastGain = lastGain_in;
 }
 
 
@@ -371,31 +378,31 @@ float DemodulatorMgr::getLastSquelchLevel() const {
     return lastSquelch;
 }
 
-void DemodulatorMgr::setLastSquelchLevel(float lastSquelch) {
-    this->lastSquelch = lastSquelch;
+void DemodulatorMgr::setLastSquelchLevel(float lastSquelch_in) {
+    lastSquelch = lastSquelch_in;
 }
 
 bool DemodulatorMgr::isLastSquelchEnabled() const {
     return lastSquelchEnabled;
 }
 
-void DemodulatorMgr::setLastSquelchEnabled(bool lastSquelchEnabled) {
-    this->lastSquelchEnabled = lastSquelchEnabled;
+void DemodulatorMgr::setLastSquelchEnabled(bool lastSquelchEnabled_in) {
+    lastSquelchEnabled = lastSquelchEnabled_in;
 }
 
 bool DemodulatorMgr::isLastMuted() const {
     return lastMuted;
 }
 
-void DemodulatorMgr::setLastMuted(bool lastMuted) {
-    this->lastMuted = lastMuted;
+void DemodulatorMgr::setLastMuted(bool lastMuted_in) {
+    lastMuted = lastMuted_in;
 }
 
-ModemSettings DemodulatorMgr::getLastModemSettings(std::string modemType) {
+ModemSettings DemodulatorMgr::getLastModemSettings(const std::string& modemType) {
     return lastModemSettings[modemType];
 }
 
-void DemodulatorMgr::setLastModemSettings(std::string modemType, ModemSettings settings) {
+void DemodulatorMgr::setLastModemSettings(const std::string& modemType, ModemSettings settings) {
     lastModemSettings[modemType] = settings;
 }
 
@@ -403,7 +410,11 @@ void DemodulatorMgr::setOutputDevices(std::map<int,RtAudio::DeviceInfo> devs) {
     outputDevices = devs;
 }
 
-void DemodulatorMgr::saveInstance(DataNode *node, DemodulatorInstancePtr inst) {
+std::map<int, RtAudio::DeviceInfo> DemodulatorMgr::getOutputDevices() {
+    return outputDevices;
+}
+
+void DemodulatorMgr::saveInstance(DataNode *node, const DemodulatorInstancePtr& inst) {
 
     *node->newChild("bandwidth") = inst->getBandwidth();
     *node->newChild("frequency") = inst->getFrequency();  
@@ -420,12 +431,12 @@ void DemodulatorMgr::saveInstance(DataNode *node, DemodulatorInstancePtr inst) {
         *node->newChild("delta_lock") = inst->isDeltaLock() ? 1 : 0;
         *node->newChild("delta_ofs") = inst->getDeltaLockOfs();
     }
-    if (inst == getLastActiveDemodulator()) {
+    if (inst == getCurrentModem()) {
         *node->newChild("active") = 1;
     }
     
     ModemSettings saveSettings = inst->readModemSettings();
-    if (saveSettings.size()) {
+    if (!saveSettings.empty()) {
         DataNode *settingsNode = node->newChild("settings");
         for (ModemSettings::const_iterator msi = saveSettings.begin(); msi != saveSettings.end(); msi++) {
             *settingsNode->newChild(msi->first.c_str()) = msi->second;
@@ -435,7 +446,7 @@ void DemodulatorMgr::saveInstance(DataNode *node, DemodulatorInstancePtr inst) {
 
 std::wstring DemodulatorMgr::getSafeWstringValue(DataNode* node) {
 
-    std::wstring decodedWString = L"";
+    std::wstring decodedWString;
 
     if (node != nullptr) {
 
@@ -443,7 +454,7 @@ std::wstring DemodulatorMgr::getSafeWstringValue(DataNode* node) {
         try {
             node->element()->get(decodedWString);
 
-        } catch (DataTypeMismatchException e) {
+        } catch (const DataTypeMismatchException &) {
             //2) wstring decode fail, try simple std::string
             std::string decodedStdString;
             try {
@@ -453,7 +464,7 @@ std::wstring DemodulatorMgr::getSafeWstringValue(DataNode* node) {
                 //use wxString for a clean conversion to a wstring:
                 decodedWString = wxString(decodedStdString).ToStdWstring();
 
-            } catch (DataTypeMismatchException e) {
+            } catch (const DataTypeMismatchException &) {
                 //nothing works, return an empty string.
                 decodedWString = L"";
             }
@@ -471,22 +482,22 @@ DemodulatorInstancePtr DemodulatorMgr::loadInstance(DataNode *node) {
 	 
     node->rewindAll();
     
-    long bandwidth = *node->getNext("bandwidth");
-    long long freq = *node->getNext("frequency");
+    long bandwidth = (long)*node->getNext("bandwidth");
+    long long freq = (long long)*node->getNext("frequency");
     float squelch_level = node->hasAnother("squelch_level") ? (float) *node->getNext("squelch_level") : 0;
     int squelch_enabled = node->hasAnother("squelch_enabled") ? (int) *node->getNext("squelch_enabled") : 0;
     int muted = node->hasAnother("muted") ? (int) *node->getNext("muted") : 0;
     int delta_locked = node->hasAnother("delta_lock") ? (int) *node->getNext("delta_lock") : 0;
     int delta_ofs = node->hasAnother("delta_ofs") ? (int) *node->getNext("delta_ofs") : 0;
-    std::string output_device = node->hasAnother("output_device") ? string(*(node->getNext("output_device"))) : "";
-    float gain = node->hasAnother("gain") ? (float) *node->getNext("gain") : 1.0;
+    std::string output_device = node->hasAnother("output_device") ? ((string)*(node->getNext("output_device"))) : "";
+    float gain = node->hasAnother("gain") ? (float) *node->getNext("gain") : 1.0f;
     
     std::string type = "FM";
     
     DataNode *demodTypeNode = node->hasAnother("type")?node->getNext("type"):nullptr;
     
-    if (demodTypeNode && demodTypeNode->element()->getDataType() == DATA_INT) {
-        int legacyType = *demodTypeNode;
+    if (demodTypeNode && demodTypeNode->element()->getDataType() == DataElement::Type::DATA_INT) {
+        int legacyType = (int)*demodTypeNode;
         int legacyStereo = node->hasAnother("stereo") ? (int) *node->getNext("stereo") : 0;
         switch (legacyType) {   // legacy demod ID
             case 1: type = legacyStereo?"FMS":"FM"; break;
@@ -507,12 +518,12 @@ DemodulatorInstancePtr DemodulatorMgr::loadInstance(DataNode *node) {
             case 16: type = "I/Q"; break;
             default: type = "FM"; break;
         }
-    } else if (demodTypeNode && demodTypeNode->element()->getDataType() == DATA_STRING) {
+    } else if (demodTypeNode && demodTypeNode->element()->getDataType() == DataElement::Type::DATA_STRING) {
         demodTypeNode->element()->get(type);
     }
     
     //read the user label associated with the demodulator
-    std::wstring user_label = L"";
+    std::wstring user_label;
     
     DataNode *demodUserLabel = node->hasAnother("user_label") ? node->getNext("user_label") : nullptr;
     
@@ -530,7 +541,7 @@ DemodulatorInstancePtr DemodulatorMgr::loadInstance(DataNode *node) {
             std::string keyName = settingNode->getName();
             std::string strSettingValue = settingNode->element()->toString();
             
-            if (keyName != "" && strSettingValue != "") {
+            if (!keyName.empty() && !strSettingValue.empty()) {
                 mSettings[keyName] = strSettingValue;
             }
         }
@@ -545,7 +556,7 @@ DemodulatorInstancePtr DemodulatorMgr::loadInstance(DataNode *node) {
     newDemod->setFrequency(freq);
     newDemod->setGain(gain);
     newDemod->updateLabel(freq);
-    newDemod->setMuted(muted?true:false);
+    newDemod->setMuted(muted != 0);
     if (delta_locked) {
         newDemod->setDeltaLock(true);
         newDemod->setDeltaLockOfs(delta_ofs);
