@@ -8,7 +8,7 @@
 
 class AboutDialog : public AboutDialogBase {
 public:
-  		AboutDialog( wxWindow* parent, wxWindowID id = wxID_ANY, const wxString& title = wxT("About"),
+  		explicit AboutDialog( wxWindow* parent, wxWindowID id = wxID_ANY, const wxString& title = wxT("About"),
                     const wxPoint& pos = wxDefaultPosition, const wxSize& size = wxSize( 530, 420 ),
                     long style = wxDEFAULT_DIALOG_STYLE );
   
