@@ -11,9 +11,7 @@ ActionDialog::ActionDialog( wxWindow* parent, wxWindowID id, const wxString& tit
 }
 
 
-ActionDialog::~ActionDialog() {
-
-}
+ActionDialog::~ActionDialog() = default;
 
 void ActionDialog::showDialog(ActionDialog *dlg) {
     if (activeDialog) { // rejected
@@ -36,7 +34,7 @@ void ActionDialog::setActiveDialog(ActionDialog *dlg) {
 }
 
 
-void ActionDialog::onClickCancel( wxCommandEvent& event ) {
+void ActionDialog::onClickCancel( wxCommandEvent& /* event */ ) {
     ActionDialog *dlg = activeDialog;
     ActionDialog::setActiveDialog(nullptr);
     dlg->EndModal(0);
@@ -45,7 +43,7 @@ void ActionDialog::onClickCancel( wxCommandEvent& event ) {
 }
 
 
-void ActionDialog::onClickOK( wxCommandEvent& event ) {
+void ActionDialog::onClickOK( wxCommandEvent& /* event */ ) {
     ActionDialog *dlg = activeDialog;
     ActionDialog::setActiveDialog(nullptr);
     dlg->EndModal(0);
