@@ -8,15 +8,15 @@
 class ModemFM : public ModemAnalog {
 public:
     ModemFM();
-    ~ModemFM();
+    ~ModemFM() override;
     
-    std::string getName();
+    std::string getName() override;
     
     static ModemBase *factory();
 
-    int getDefaultSampleRate();
+    int getDefaultSampleRate() override;
 
-    void demodulate(ModemKit *kit, ModemIQData *input, AudioThreadInput *audioOut);
+    void demodulate(ModemKit *kit, ModemIQData *input, AudioThreadInput *audioOut) override;
 
 private:
     freqdem demodFM;
