@@ -4,11 +4,11 @@
 #include "ModemOOK.h"
 
 ModemOOK::ModemOOK() : ModemDigital()  {
-    demodOOK = modem_create(LIQUID_MODEM_OOK);
+    demodOOK = modemcf_create(LIQUID_MODEM_OOK);
 }
 
 ModemOOK::~ModemOOK() {
-    modem_destroy(demodOOK);
+    modemcf_destroy(demodOOK);
 }
 
 std::string ModemOOK::getName() {
@@ -19,19 +19,19 @@ ModemBase *ModemOOK::factory() {
     return new ModemOOK;
 }
 
-int ModemOOK::checkSampleRate(long long sampleRate, int audioSampleRate) {
+int ModemOOK::checkSampleRate(long long sampleRate, int /* audioSampleRate */) {
     if (sampleRate < 100) {
         return 100;
     }
     return (int)sampleRate;
 }
 
-void ModemOOK::demodulate(ModemKit *kit, ModemIQData *input, AudioThreadInput *audioOut) {
-    ModemKitDigital *dkit = (ModemKitDigital *)kit;
+void ModemOOK::demodulate(ModemKit *kit, ModemIQData *input, AudioThreadInput * /* audioOut */) {
+    auto *dkit = (ModemKitDigital *)kit;
     digitalStart(dkit, demodOOK, input);
    
     for (size_t i = 0, bufSize=input->data.size(); i < bufSize; i++) {
-        modem_demodulate(demodOOK, input->data[i], &demodOutputDataDigital[i]);
+        modemcf_demodulate(demodOOK, input->data[i], &demodOutputDataDigital[i]);
     }
     updateDemodulatorLock(demodOOK, 0.005f);
     
