@@ -7,14 +7,14 @@
 class ModemQPSK : public ModemDigital {
 public:
     ModemQPSK();
-    ~ModemQPSK();
+    ~ModemQPSK() override;
     
-    std::string getName();
+    std::string getName() override;
     
     static ModemBase *factory();
 
-    void demodulate(ModemKit *kit, ModemIQData *input, AudioThreadInput *audioOut);
+    void demodulate(ModemKit *kit, ModemIQData *input, AudioThreadInput *audioOut) override;
     
 private:
-    modem demodQPSK;
+    modemcf demodQPSK;
 };
