@@ -2,10 +2,8 @@
 // SPDX-License-Identifier: GPL-2.0+
 
 #include "SDRPostThread.h"
-#include "CubicSDRDefs.h"
 #include "CubicSDR.h"
 
-#include <vector>
 #include <deque>
 #include <memory>
 
@@ -33,6 +31,7 @@ SDRPostThread::SDRPostThread() : IOThread(), buffers("SDRPostThreadBuffers"), vi
 
 
 SDRPostThread::~SDRPostThread() {
+    iirfilt_crcf_destroy(dcFilter);
 }
 
 
@@ -50,10 +49,10 @@ void SDRPostThread::updateActiveDemodulators() {
 
     long long centerFreq = wxGetApp().getFrequency();
 
-    //retreive the current list of demodulators:
+    //retrieve the current list of demodulators:
     auto demodulators = wxGetApp().getDemodMgr().getDemodulators();
    
-    for (auto demod : demodulators) {
+    for (const auto& demod : demodulators) {
             
         // not in range?
         if (demod->isDeltaLock()) {
@@ -68,8 +67,7 @@ void SDRPostThread::updateActiveDemodulators() {
         if (abs(frequency - demod->getFrequency()) > (sampleRate / 2)) {
             // deactivate if active
            
-            if (wxGetApp().getDemodMgr().getLastActiveDemodulator() == demod) {
-
+            if (wxGetApp().getDemodMgr().getCurrentModem() == demod) {
                 demod->setActive(false);
             }
             else if (demod->isActive() && !demod->isFollow() && !demod->isTracking()) {
@@ -83,7 +81,7 @@ void SDRPostThread::updateActiveDemodulators() {
             }
         } else if (!demod->isActive()) { // in range, activate if not activated
             demod->setActive(true);
-            if (wxGetApp().getDemodMgr().getLastActiveDemodulator() == nullptr) {
+            if (wxGetApp().getDemodMgr().getCurrentModem() == nullptr) {
 
                 wxGetApp().getDemodMgr().setActiveDemodulator(demod);
             }
@@ -94,7 +92,6 @@ void SDRPostThread::updateActiveDemodulators() {
         }
         
         // Add active demods to the current run:
-
         runDemods.push_back(demod);
         demodChannel.push_back(-1);
     }
@@ -102,10 +99,10 @@ void SDRPostThread::updateActiveDemodulators() {
 
 
 void SDRPostThread::resetAllDemodulators() {
-    //retreive the current list of demodulators:
+    //retrieve the current list of demodulators:
     auto demodulators = wxGetApp().getDemodMgr().getDemodulators();
 
-    for (auto demod : demodulators) {
+    for (const auto& demod : demodulators) {
 
         demod->setActive(false);
         demod->getIQInputDataPipe()->flush();
@@ -128,11 +125,11 @@ void SDRPostThread::updateChannels() {
 
 
 // Find the channelizer channel that corresponds to the given frequency
-int SDRPostThread::getChannelAt(long long frequency) {
+int SDRPostThread::getChannelAt(long long frequency_in) {
     int chan = -1;
     long long minDelta = sampleRate;
     for (int i = 0; i < numChannels+1; i++) {
-        long long fdelta = abs(frequency - chanCenters[i]);
+        long long fdelta = abs(frequency_in - chanCenters[i]);
         if (fdelta < minDelta) {
             minDelta = fdelta;
             chan = i;
@@ -176,10 +173,8 @@ void SDRPostThread::run() {
          
         bool doUpdate = false;
 
-        if (data_in && data_in->data.size()) {
-            
-            pushVisualData(data_in.get());
-            
+        if (data_in && !data_in->data.empty()) {
+           
             if(data_in->numChannels > 1) {
                 if (chanMode == 1) {
                     runPFBCH(data_in.get());
@@ -191,8 +186,7 @@ void SDRPostThread::run() {
             }
         }
         
-        for (size_t j = 0; j < runDemods.size(); j++) {
-            DemodulatorInstancePtr demod = runDemods[j];
+        for (const auto& demod : runDemods) {
             if (abs(frequency - demod->getFrequency()) > (sampleRate / 2)) {
                 doUpdate = true;
             }
@@ -223,27 +217,29 @@ void SDRPostThread::terminate() {
     iqActiveDemodVisualQueue->flush();
 }
 
+// Copy the full badwidth into a new DemodulatorThreadIQDataPtr.
+DemodulatorThreadIQDataPtr SDRPostThread::getFullSampleRateIqData(SDRThreadIQData *data_in) {
+
+    DemodulatorThreadIQDataPtr iqDataOut = visualDataBuffers.getBuffer();
+
+    iqDataOut->frequency = data_in->frequency;
+    iqDataOut->sampleRate = data_in->sampleRate;
+    iqDataOut->data.assign(data_in->data.begin(), data_in->data.begin() + data_in->data.size());
+
+    return iqDataOut;
+}
+
 // Push visual data; i.e. Main Waterfall (all frames) and Spectrum (active frame)
-void SDRPostThread::pushVisualData(SDRThreadIQData *data_in) {
-    if (iqDataOutQueue != nullptr && !iqDataOutQueue->full()) {
-        DemodulatorThreadIQDataPtr iqDataOut = visualDataBuffers.getBuffer();
+void SDRPostThread::pushVisualData(const DemodulatorThreadIQDataPtr& iqDataOut) {
+
+    if (iqDataOutQueue != nullptr) {
         
-        bool doVis = false;
-        
-        if (iqVisualQueue != nullptr && !iqVisualQueue->full()) {
-            doVis = true;
-        }
-        
-        iqDataOut->frequency = data_in->frequency;
-        iqDataOut->sampleRate = data_in->sampleRate;
-        iqDataOut->data.assign(data_in->data.begin(), data_in->data.begin() + data_in->data.size());
-        
-        //VSO: blocking push
-        iqDataOutQueue->push(iqDataOut);
-        
-        if (doVis) {
-            //VSO: blocking push
-            iqVisualQueue->push(iqDataOut);
+        //non-blocking push here, we can afford to loose some samples for a ever-changing visual display.
+        iqDataOutQueue->try_push(iqDataOut);
+
+        if (iqVisualQueue != nullptr) {
+            //non-blocking push here, we can afford to loose some samples for a ever-changing visual display.
+            iqVisualQueue->try_push(iqDataOut);
         }
     }
 }
@@ -284,39 +280,28 @@ void SDRPostThread::runSingleCH(SDRThreadIQData *data_in) {
         demodDataOut->data.resize(outSize);
     }
     
+    //Only 1 channel, apply DC blocker.
     iirfilt_crcf_execute_block(dcFilter, &data_in->data[0], data_in->data.size(), &demodDataOut->data[0]);
 
-    if (runDemods.size() > 0 && iqActiveDemodVisualQueue != nullptr && !iqActiveDemodVisualQueue->full()) {
-        //VSO: blocking push
-        iqActiveDemodVisualQueue->push(demodDataOut);
-    }
-    
-    if (iqDataOutQueue != nullptr && !iqDataOutQueue->full()) {
-        //VSO: blocking push
-        iqDataOutQueue->push(demodDataOut);
-    }
+    //push the DC-corrected data as Main Spactrum + Waterfall data.
+    pushVisualData(demodDataOut);
 
-    if (iqVisualQueue != nullptr && !iqVisualQueue->full()) {
-        //VSO: blocking push
-        iqVisualQueue->push(demodDataOut);
+    if (!runDemods.empty() && iqActiveDemodVisualQueue != nullptr) {
+        //non-blocking push here, we can afford to loose some samples for a ever-changing visual display.
+        iqActiveDemodVisualQueue->try_push(demodDataOut);
     }
     
-    for (size_t i = 0; i < runDemods.size(); i++) {
+    for (auto & runDemod : runDemods) {
         // try-push() : we do our best to only stimulate active demods, but some could happen to be dead, full, or indeed non-active.
         //so in short never block here no matter what.
-        if (!runDemods[i]->getIQInputDataPipe()->try_push(demodDataOut)) {
-
-         //   std::cout << "SDRPostThread::runSingleCH() attempt to push into demod '" << runDemods[i]->getLabel()
-         //       << "' (" << runDemods[i]->getFrequency() << " Hz) failed, demod is either too busy, not-active, or dead..." << std::endl << std::flush;
-            std::this_thread::yield();
-        }
+        runDemod->getIQInputDataPipe()->try_push(demodDataOut);
     }
 }
 
 
 // Handle active channels, channel 0 offset correction, de-interlacing and push data to demodulators
 void SDRPostThread::runDemodChannels(int channelBandwidth) {
-    DemodulatorInstancePtr activeDemod = wxGetApp().getDemodMgr().getLastActiveDemodulator();
+    DemodulatorInstancePtr activeDemod = wxGetApp().getDemodMgr().getCurrentModem();
 
     // Calculate channel data size
     size_t chanDataSize = dataOut.size()/numChannels;
@@ -346,7 +331,7 @@ void SDRPostThread::runDemodChannels(int channelBandwidth) {
 
     // Run channels
     for (int i = 0; i < numChannels+1; i++) {
-        bool doDemodVis = (activeDemodChannel == i) && (iqActiveDemodVisualQueue != nullptr) && !iqActiveDemodVisualQueue->full();
+        bool doDemodVis = (activeDemodChannel == i) && (iqActiveDemodVisualQueue != nullptr);
         
         if (!doDemodVis && demodChannelActive[i] == 0) {
             // Nothing to do for this channel? continue.
@@ -397,8 +382,8 @@ void SDRPostThread::runDemodChannels(int channelBandwidth) {
         }
         
         if (doDemodVis) {
-            //VSO: blocking push
-            iqActiveDemodVisualQueue->push(demodDataOut);
+            //non-blocking push here, we can afford to loose some samples for a ever-changing visual display.
+            iqActiveDemodVisualQueue->try_push(demodDataOut);
         }
         
         for (size_t j = 0; j < runDemods.size(); j++) {
@@ -406,11 +391,7 @@ void SDRPostThread::runDemodChannels(int channelBandwidth) {
                 
                 // try-push() : we do our best to only stimulate active demods, but some could happen to be dead, full, or indeed non-active.
                 //so in short never block here no matter what.
-                if (!runDemods[j]->getIQInputDataPipe()->try_push(demodDataOut)) {
-                    //    std::cout << "SDRPostThread::runPFBCH() attempt to push into demod '" << runDemods[i]->getLabel()
-                    //        << "' (" << runDemods[i]->getFrequency() << " Hz) failed, demod is either too busy, not-active, or dead..." << std::endl << std::flush;
-                    std::this_thread::yield();
-                }
+                runDemods[j]->getIQInputDataPipe()->try_push(demodDataOut);
             }
         } //end for
     }
@@ -447,6 +428,10 @@ void SDRPostThread::runPFBCH(SDRThreadIQData *data_in) {
         updateActiveDemodulators();
         updateChannels();
     }
+
+    //push the full data_in into (Main spectrum + waterfall) visual queue:
+    DemodulatorThreadIQDataPtr fullSampleRateIQ = getFullSampleRateIqData(data_in);
+    pushVisualData(fullSampleRateIQ);
     
     size_t outSize = data_in->data.size();
     
@@ -458,7 +443,7 @@ void SDRPostThread::runPFBCH(SDRThreadIQData *data_in) {
     }
     
     // Find active demodulators
-    if (runDemods.size() > 0) {
+    if (!runDemods.empty()) {
         // Channelize data
         // firpfbch produces [numChannels] interleaved output samples for every [numChannels] samples
         for (int i = 0, iMax = data_in->data.size(); i < iMax; i+=numChannels) {
@@ -499,6 +484,10 @@ void SDRPostThread::runPFBCH2(SDRThreadIQData *data_in) {
         updateActiveDemodulators();
         updateChannels();
     }
+
+    //push the full data_in into (Main spectrum + waterfall) visual queue:
+    DemodulatorThreadIQDataPtr fullSampleRateIQ = getFullSampleRateIqData(data_in);
+    pushVisualData(fullSampleRateIQ);
     
     size_t outSize = data_in->data.size() * 2;
     
@@ -510,7 +499,7 @@ void SDRPostThread::runPFBCH2(SDRThreadIQData *data_in) {
     }
     
     // Find active demodulators
-    if (runDemods.size() > 0) {
+    if (!runDemods.empty()) {
         // Channelize data
         // firpfbch2 produces [numChannels] interleaved output samples for every [numChannels/2] input samples
         for (int i = 0, iMax = data_in->data.size(); i < iMax; i += numChannels/2) {
