@@ -6,8 +6,6 @@
 #include "PrimaryGLContext.h"
 #include "Gradient.h"
 
-#define NUM_WATERFALL_LINES 512
-
 class ModeSelectorCanvas;
 
 class ModeSelectorContext: public PrimaryGLContext {
@@ -15,6 +13,6 @@ public:
     ModeSelectorContext(ModeSelectorCanvas *canvas, wxGLContext *sharedContext, wxGLContextAttrs *ctxAttrs);
 
     void DrawBegin();
-    void DrawSelector(std::string label, int c, int cMax, bool on, float r, float g, float b, float a, float padx, float pady);
+    void DrawSelector(const std::string& label, int c, int cMax, bool on, float r, float g, float b, float a, float padx, float pady);
     void DrawEnd();
 };
