@@ -6,8 +6,6 @@
 #include "PrimaryGLContext.h"
 #include "Gradient.h"
 
-#define NUM_WATERFALL_LINES 512
-
 class TuningCanvas;
 
 class TuningContext: public PrimaryGLContext {
@@ -17,9 +15,9 @@ public:
     void DrawBegin();
     void Draw(float r, float g, float b, float a, float p1, float p2);
     void DrawTuner(long long freq, int count, float displayPos, float displayWidth);
-    void DrawTunerDigitBox(int index, int count, float displayPos, float displayWidth, RGBA4f c);
+    static void DrawTunerDigitBox(int index, int count, float displayPos, float displayWidth, const RGBA4f& c);
     int GetTunerDigitIndex(float mPos, int count, float displayPos, float displayWidth);
-    void DrawTunerBarIndexed(int start, int end, int count, float displayPos, float displayWidth, RGBA4f color, float alpha, bool top, bool bottom);
+    void DrawTunerBarIndexed(int start, int end, int count, float displayPos, float displayWidth, const RGBA4f& color, float alpha, bool top, bool bottom);
 
     void DrawDemodFreqBw(long long freq, unsigned int bw, long long center);
     void DrawEnd();
